@@ -152,10 +152,10 @@ def jsdoc(files, folder, template = None, fail = True):
     
     console.confirm('  Doc generated in "%s"' % folder)
 
-def patch(dir, patch):
+def patch(dir, patch, p=0):
     # patch -p0 -N <
 
-    output = sh(['cd %s' % dir, 'patch -p0 -N -r pukepatch.rej < %s' % patch], output = False)
+    output = sh(['cd %s' % dir, 'patch -p%s -N -r pukepatch.rej < %s' % (p, patch)], output = False)
     console.header(' - Patching %s with %s' % (dir, patch))
     lines = output.split('\n')
     for line in lines:
@@ -170,8 +170,10 @@ def patch(dir, patch):
         else:
             console.info('    ' + line)
     
-    remove(join(dir, 'pukepatch.rej'))
-        
+    try:
+        remove(join(dir, 'pukepatch.rej'))
+    except:
+        pass
 
 
 def prompt(message, default = ''):
@@ -224,7 +226,7 @@ def deepcopy(file_list, folder, replace = None):
     for (file, basepath) in file_list:
         
         if basepath:
-            dst_file = __pretty(file).replace(basepath, '').strip('/')
+            dst_file = __pretty(file).replace(basepath, '').strip(os.sep)
             dst_file = os.path.join(folder,dst_file)
         else:
             dst_file = os.path.join(folder,os.path.basename(__pretty(file)))
@@ -316,12 +318,13 @@ def pack (file_list, output):
 
     console.confirm(" %s packed" % output)
 
-def unpack (pack_file, output, extract = None):
+def unpack (pack_file, output, extract = None, verbose=True):
     
     console.header( "- Unpacking %s to %s " % (pack_file, output))
 
     if not Compress.check(pack_file):
         console.error(" %s is not a valid pack" % output)
+        raise PukeError('%s is not a valid pack' % output)
         return
 
     comp = Compress.open(pack_file, "r")
@@ -333,15 +336,27 @@ def unpack (pack_file, output, extract = None):
         if extract and extract not in fname:
             continue
 
-        data = comp.extract(fname)
+        (data, infos) = comp.extract(fname)
         
+       
         #folder
         if not data:
             continue
-
+        
         output_file = os.path.join(output, fname)
-        console.info(' + %s' % __pretty(output_file))
-        writefile(output_file, data)
+
+
+        if exists(output_file) and os.path.getmtime(output_file) == infos.mtime:
+            continue
+        
+        if verbose == True:
+            console.info(' + %s' % __pretty(output_file))
+        
+        writefile(output_file, data, mtime=infos.mtime)
+
+        if infos.mode:
+            chmod(output_file, infos.mode)
+
         count += 1
     
     comp.close()
@@ -399,7 +414,7 @@ def __replace(data, replace):
 
 def __pretty(filename):
     if filename.startswith('.pukecache'):
-        return Cache.getInfo(filename.split('/').pop())
+        return Cache.getInfo(filename.split(os.sep).pop())
     
     return filename
 
